package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````H1<``#0```"D@0````0`!30`(``)
M`"@`&P`:``$``'`H>@``*'H``"AZ```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$````````````````````T>@``-'H```4```````$`
M`0```(1]``"$?0$`A'T!`+P"``#4$@``!@```````0`"````C'T``(Q]`0",
M?0$`*`$``"@!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DA'T`
M`(1]`0"$?0$`?`(``'P"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````,````"``````````0````4
M`````P```$=.50"-*M677C?68Q+F*KOCR8_Q6NHA&Q$```!0````"`````@`
M```!D!`$)4`$@"B```&@AE"`@`$```LH!(TXH!)%B@0("%````!1````50``
M`%H```!;````8@```&,```!D````9@```&<`````````:0```&H```!K````
M;0```````````````:\TZ&[%WQ_JT^\.SMY'+6M_FGPNQ9NV=E0\E"#_Y`ZX
MC?$.U634?-EQ6!SB1\8!K$OCP+KCDGQ8[Y=YPN4_+/JA;&"S`8MO:PE#UF>O
MS&9"1=7LB0=PTPT4XI[:S>.>,V+;[0TZEPM_J9R;OMI7&^&G`@JCX/M)````
M``````````````````````"X$@````````,`"P```````(`!```````#`!8`
MMP(`````````````$@```&4#`````````````!(````Y`P`````````````B
M````?@,`````````````$0```/T#`````````````!(````1````````````
M```@````*@(`````````````$@````L#`````````````!(```!6`P``````
M```````2````$0$`````````````$@```)P#`````````````!$```"T````
M```````````2````T@(`````````````$@```(,!`````````````!(```"^
M`@`````````````2````A```````````````$@````P!`````````````!(`
M``#9`@`````````````2````FP(`````````````$@```&$"````````````
M`!(````Y`@`````````````2````<@(`````````````$@```'\"````````
M`````!(````!`0`````````````1````9P$`````````````$@```.,`````
M`````````!$````U`0`````````````2````$@,`````````````$@````0#
M`````````````!$````;`P`````````````2````P@``````````````$@``
M`+$!`````````````!(````B`@`````````````2````G@$`````````````
M$@```/("`````````````!(````*`@`````````````2````J@$`````````
M````$@```&P#`````````````!(```!#`0`````````````2````+0``````
M````````(````)0"`````````````!(```!+`@`````````````2````J0(`
M````````````$@```+P!`````````````!$```!D```````````````2````
M*`,`````````````$@```),``````````````!(````1`@`````````````2
M````2`,`````````````$@```)\``````````````!(```!<`0``````````
M```2````>0(`````````````$@```+`"`````````````!(````B`0``````
M```````2````5@``````````````$@```!8!`````````````!(```"3`0``
M```````````2````Q`(`````````````$@```/```````````````!(```"-
M`@`````````````2````7@,`````````````$@```*("`````````````!(`
M``!U`0`````````````2````<P``````````````$@```'\#````````````
M`"$````O`P`````````````2````U```````````````$@```%,!````````
M`````!(````\```````````````@````@`,`````````````$0```/H"````
M`````````!(```!0`@`````````````2````AP(`````````````$@````0"
M`````````````!(```#G`@`````````````2````6`(`````````````$@``
M`/`!`````````````!(````:!```6)`!```````0`!<`!@0``-4Y``!0````
M$@`-`,8#``!X.@```````!(`#@`^!```X2\``#0'```2``T`>0,``.D5``"X
M`0``$@`-`,P#``#1*@``!````!(`#0#=`P``0(`!```````0`!<`Q00``-4J
M``"@`0``$@`-`+\$``"X$@```````!(`"P#R!```%3<``,`"```2``T`L00`
M`$"``0``````$``7`"4$``!U+```%@```!(`#0!8!```@#H```0````1``\`
MEP0``%B0`0``````$``7`)P$``!8D`$``````!``%P"]!```N2D``#@````2
M``T`T@0``$$O``"@````$@`-`.0$``#1+@``8````!(`#0!+!````(`!````
M```0`!8`,@0``(TL``#`````$@`-`!($``!`@`$``````!``%@"-!```/(`!
M``0````1`!8`O`,``'4Z```"````$@`-`'T$```U.@``0````!(`#0!1!```
MH1<````````2``T`300```"``0``````(``6`.L#```Q+P``$````!(`#0`9
M!```6)`!```````0`!<`9P0``#TJ``"4````$@`-`*0$``!-+0``A`$``!(`
M#0``;&EB<&5R;"YS;RXU+C(X`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!?7V=M;VY?<W1A<G1?7P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E
M<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P
M97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X
M=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T
M<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`
M<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L
M7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3
M`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`
M<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M
M96UO<GE?=W)A<`!L:6)D;"YS;RXR`&QI8FTN<V\N-@!L:6)P=&AR96%D+G-O
M+C``<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!O<&5N-C0`7U]E<G)N;U]L
M;V-A=&EO;@!L<V5E:S8T`')E860`;&EB8RYS;RXV`%]?<F5G:7-T97)?871F
M;W)K`&5X:70`<W1R;F-M<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N
M;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE;6-H<@!G971P:60`<W1R9'5P
M`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?
M8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?
M7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN:P!?7VUE;6-P>5]C:&L`
M<W1R8VAR`')E861D:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P<FEN=&9?8VAK
M`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N
M=FER;VX`;&0M;&EN=7@M87)M:&8N<V\N,P!?7W-T86-K7V-H:U]G=6%R9`!L
M:6)C<GEP="YS;RXQ`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C
M`%]?8G-S7W-T87)T7U\`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R
M7V-L96%N=7``7V5D871A`%]?8G-S7V5N9%]?`'!A<E]B87-E;F%M90!P87)?
M9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T87)T`%])3U]S=&1I;E]U
M<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?
M<&%R7W!L`%]E;F0`7U]E;F1?7P!P87)?:6YI=%]E;G8`7U]B<W-?<W1A<G0`
M>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N
M=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXT````````
M``(``@`"``(``@````,``@`"``(`!`````(````"```````"``(``@`"``(`
M`@````````````(``@`"```````#`````@`#``(``@```````@`"``(`````
M``(````#``(```````(``@````````````(````"``(``@```````@`"````
M``````(``@`"``(``P`"``(``P`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0````$``0"(`P``
M$````"`````4:6D-```$``@%`````````0`!`.`!```0````(````!1I:0T`
M``,`"`4````````!``$`+P(``!``````````%&EI#0```@`(!0```````(1]
M`0`7````B'T!`!<```#`?P$`%P```.A_`0`7````\'\!`!<````$@`$`%P``
M``R``0`7````$(`!`!<````8@`$`%P```!R``0`7````((`!`!<````D@`$`
M%P```"B``0`7````,(`!`!<````T@`$`%P```#R``0`7````Q'\!`!4%``#(
M?P$`%0@``,Q_`0`5#0``T'\!`!40``#4?P$`%1H``-A_`0`5'```W'\!`!4?
M``#@?P$`%2H``.1_`0`5+@``['\!`!4X``#T?P$`%4(``/A_`0`51P``_'\!
M`!5(``#`?@$`%@,``,1^`0`6!```R'X!`!8%``#,?@$`%@<``-!^`0`6"0``
MU'X!`!8*``#8?@$`%@L``-Q^`0`6#```X'X!`!8.``#D?@$`%@\``.A^`0`6
M$0``['X!`!82``#P?@$`%A,``/1^`0`6%```^'X!`!85``#\?@$`%A8```!_
M`0`6%P``!'\!`!88```(?P$`%AD```Q_`0`6&P``$'\!`!8=```4?P$`%AX`
M`!A_`0`6(```''\!`!8A```@?P$`%B(``"1_`0`6(P``*'\!`!8D```L?P$`
M%B4``#!_`0`6)@``-'\!`!8G```X?P$`%B@``#Q_`0`6*0``0'\!`!8J``!$
M?P$`%BL``$A_`0`6+```3'\!`!8M``!0?P$`%B\``%1_`0`6,```6'\!`!8Q
M``!<?P$`%C(``&!_`0`6,P``9'\!`!8T``!H?P$`%C4``&Q_`0`6-@``<'\!
M`!8W``!T?P$`%CD``'A_`0`6.@``?'\!`!8[``"`?P$`%CP``(1_`0`6/0``
MB'\!`!8^``",?P$`%C\``)!_`0`60```E'\!`!9!``"8?P$`%D0``)Q_`0`6
M10``H'\!`!9&``"D?P$`%DD``*A_`0`62@``K'\!`!9+``"P?P$`%DP``+1_
M`0`630``N'\!`!9.``"\?P$`%D\```A`+>E)`0#K"("]Z`3@+>4$X)_E#N"/
MX`CPON7@:P$``,:/XA;*C.+@^[SE`,:/XA;*C.+8^[SE`,:/XA;*C.+0^[SE
M`,:/XA;*C.+(^[SE`,:/XA;*C.+`^[SE`,:/XA;*C.*X^[SE`,:/XA;*C.*P
M^[SE`,:/XA;*C.*H^[SE`,:/XA;*C.*@^[SE`,:/XA;*C.*8^[SE`,:/XA;*
MC.*0^[SE`,:/XA;*C.*(^[SE`,:/XA;*C.*`^[SE`,:/XA;*C.)X^[SE>$?`
M1@#&C^(6RHSB;/N\Y0#&C^(6RHSB9/N\Y7A'P$8`QH_B%LJ,XEC[O.4`QH_B
M%LJ,XE#[O.4`QH_B%LJ,XDC[O.4`QH_B%LJ,XD#[O.4`QH_B%LJ,XCC[O.4`
MQH_B%LJ,XC#[O.4`QH_B%LJ,XBC[O.4`QH_B%LJ,XB#[O.4`QH_B%LJ,XAC[
MO.4`QH_B%LJ,XA#[O.4`QH_B%LJ,X@C[O.4`QH_B%LJ,X@#[O.4`QH_B%LJ,
MXOCZO.4`QH_B%LJ,XO#ZO.4`QH_B%LJ,XNCZO.4`QH_B%LJ,XN#ZO.4`QH_B
M%LJ,XMCZO.4`QH_B%LJ,XM#ZO.4`QH_B%LJ,XLCZO.4`QH_B%LJ,XL#ZO.4`
MQH_B%LJ,XKCZO.4`QH_B%LJ,XK#ZO.4`QH_B%LJ,XJCZO.4`QH_B%LJ,XJ#Z
MO.4`QH_B%LJ,XICZO.4`QH_B%LJ,XI#ZO.5X1\!&`,:/XA;*C.*$^KSE`,:/
MXA;*C.)\^KSE`,:/XA;*C.)T^KSE`,:/XA;*C.)L^KSE`,:/XA;*C.)D^KSE
M`,:/XA;*C.)<^KSE`,:/XA;*C.)4^KSE`,:/XA;*C.),^KSE`,:/XA;*C.)$
M^KSE`,:/XA;*C.(\^KSE`,:/XA;*C.(T^KSE`,:/XA;*C.(L^KSE`,:/XA;*
MC.(D^KSE`,:/XA;*C.(<^KSE`,:/XA;*C.(4^KSE`,:/XA;*C.(,^KSE`,:/
MXA;*C.($^KSE`,:/XA;*C.+\^;SE`,:/XA;*C.+T^;SE`,:/XA;*C.+L^;SE
M`,:/XA;*C.+D^;SE`,:/XA;*C.+<^;SE`````/"UB;!93%I+?$0%D`21!:@#
MD@2IYE@#JC-H!Y/_]T3O5$I52Z)8X%@11@+P!_I32^-8'W@`+VK044OE6"AH
M__?8[Y#XQC,"1BAH0_`"`X+XQC/_]\[O!9L%,[/Q@$^0^,8C0O`!`H#XQB-S
MTI@`!"?_]][N0TH$G7I$0TL1:'M$0DHL:'I$0V#`Z0(20$L%FGM$!&`!*L/I
M`7#"OP#Q#`$K'07K@@4%W5/X!$N=0D'X!$_YT3=/`O&`00`D`S%_1`"40/@A
M0`-&/6D#,C))*$9Y1/_W+N\$1DBS,$T&KWU$*&G_]WSN+D@Y1GA$`/`R_Q"S
M+$M[1!AI__="[O_W#.\'FC-H($::0BW1";#PO?_WA.XE2GI$$&$0L__W+.X8
M2^58*&C_]V3O@/AQ=X;G.&G_]S3O!$;0Y^AH$+$"\%;YU^<:2#E&>$0`\`3_
MZ&``*,_0\^<62Q=(X5AX1/_WPNX!(/_WEN[_]R#N`+_`:`$`&`$``#@!``!`
M`0``)`$``"`!``#8:0$`6B<``%@G``#(:0$`FFD!`#43``!Z:0$`IB0``&1I
M`0!$:0$`YB,``#`!``"V)0``3_``"T_P``X"O&I&!+0!M-_X)*`(HYI$W_@@
MP%KX#,!-^`3-!DM:^`,P!DA:^```__<Z[O_WZ.[<9@$`#`$``#0!```\`0``
M%#"?Y10@G^4#,(_@`B"3YP``4N,>_R\!%O__ZKQF`0`L`0``!D@'2WA$!TI[
M1(-">D0#T`5+TU@#L1A'<$<`ORQH`0`H:`$`F&8!`!0!```(2`E+>$0)2GM$
M&1IZ1(D0`>O1<4D0`]`%2]-8`[$81W!'`+\`:`$`_&<!`&QF`0!$`0``"+4*
M2PI*>T1Z1!MX:[D)2]-8([$(2WM$&&C_]S3M__>__P9+`2)[1!IP"+W*9P$`
M/&8!`!`!``!^9P$`JF<!`,3G`+_?^(`\`/%``2WI\$][1-_X>$RM]25]`JT`
M\8`'`"8;62I&O$8!DQMHHY-1Z0)T"#&,159@UF`_ND_J%"-/Z@0N`_1_0P[T
M?PY#ZA1C%V!#Z@1C`O$0`D/J#@-"^`@\Y-$%]?QU:48`)H9&C$91^`@/W/AP
M(-SX2#"I0MSX&'#<^'1`@^H"`]SX3""#Z@<#W/@<<(/J``."Z@0"3&B"Z@<"
M3^K3=X+J!`+!^(1@1^I"!T?J0P/!^(`PU]%P1M[I`F/>Z0#$!VE/ZI8.@FE.
MZH-^`IE/ZMQEA^H""4?VF1,":L7V@B-%ZD05R1A%ZDP5B1AI&(5I!)H)Z@8)
M3NJ&?HGJ!0E/ZIP%$>L)`8?J#@A%ZH1UU!B":0CJ#`A%ZHQUB.H'"*08!IJ.
MZ@4)%.L(!$_J\6@4ZP@$">H!"1+K`PA/ZK$!B>H.`ACK!PC=^""03^KT:ACK
M`@*%Z@$($NL*`@CJ!`@9ZP,)3^JT!(CJ!0@9ZPX.W?@HD$_J\FH>ZP@.@>H$
M"![K"@X(Z@((&>L#"4_JL@*(Z@$(&>L%!=WX,)!/ZOYJ%>L(!83J`@@5ZPH%
M".H."!GK`PE/ZKX.B.H$"!GK`0'=^#B@$>L(`8+J#@E/ZO5H$>L("`GJ!0D:
MZP,*3^JU`8GJ`@D:ZP0$W?A`H([J`044ZPD$3^KX:13K"00%Z@@%&NL#"D_J
MN`B%Z@X%&NL"`MWX2*!2&8'J"`E/ZO1E51D)Z@0)&NL#"@I&&NL.#D_JM`'=
M^%"@B>H"!![K!`1/ZO5IB.H!#A3K"00.Z@4.&NL#"4_JM049ZP()CNH(#D)&
MW?A8@$_J]&H9ZPX.@>H%"1[K"@X)Z@0)&.L#"-WX8*`8ZP((3^JT`HGJ`01/
MZOYI&.L$!(7J`@@4ZPD$".H."!KK`PE/ZKX.&>L!"8CJ!0@I1AJ=3^KT:AGK
M"`B"Z@X)&.L*"`GJ!`GM&&T8W?APH$_JM`&)Z@($+!E/ZOAICNH!!13K"00%
MZ@@%&NL#"4_JN`@9ZP()<D;=^'C@54!/ZO1J&>L%!8'J"`D5ZPH%">H$"1[K
M`P[=^("@'NL"#D_JM`*)Z@$$3^KU:1[K!`2(Z@(.%.L)!`[J!0X:ZP,)3^JU
M!8[J"`X9ZP$)04;=^(B`3^KT:AGK#@F"Z@4.&>L*"0[J!`X8ZP,(3^JT!([J
M`@X8ZP$!W?B0@$_J^6H1ZPX!A>H$#A'K"@$.Z@D.&.L#"$_JN0F.Z@4.&.L"
M`MWXF(!/ZO%J$NL.`H3J"0X2ZPH"#NH!#ACK`PA/ZK$!&.L%!8[J!`C=^*#@
M3^KR:A7K"`B)Z@$%&.L*"!5`'NL##H7J"04>ZP0.*IM/ZK("'NL%#D[VH31/
MZOAEQO;99![K!0Z!Z@(%&QF%Z@@%$^L)"2R;3^JX"!GK!0E/ZOYE&>L%"8+J
M"`4;&87J#@5;&"Z93^J^#EL93^KY95L9B.H.!0D9A>H)!8D8,)I/ZKD)31E/
MZO-A;1B.Z@D!$AE90!+K"`@RFD_JLP,8ZP$!3^KU:(GJ`PH1ZP@!$AF*Z@4*
MW?C0@!+K#@)/ZK4%3^KQ;A+K"@(2ZPX"@^H%"ACK!`Z*Z@$*'NL)#MWXV(!/
MZK$!3^KR:1[K"@[=^/"@'NL)#H7J`0D8ZP0(B>H""1CK`P/=^."`$^L)"4_J
ML@-/ZOYB&>L"`H'J`PD8ZP0(B>H."1CK!0@ZG4_JO@X8ZPD(3^KR:1CK"0B#
MZ@X)+1F)Z@():1A/ZK(%$>L)`4_J^&*)&([J!0D:ZP0"B>H("=WX^*#2&!+K
M"0)/ZK@#3^KQ:(7J`PD2ZP@"&NL$"(GJ`0G=^`"A&.L."$_JL0%/ZO)N&.L)
M"!CK#@B#Z@$)&NL$#HGJ`@D>ZP4.0IU/ZK("'NL)#D_J^&G=^!"A'NL)#H'J
M`@DM&8GJ"`GK&$_JN`43ZPD#3^K^:!/K"`."Z@4)&NL$"(GJ#@D8ZP$!W?@8
MH1'K"0E/ZKX!3^KS;H7J`0@9ZPX)&NL$#A[K`@*(Z@,(W?@@X1+K"`A/ZK,"
M3^KY8QCK`PB!Z@(*'NL$`XKJ"0I=&=WX*.%/ZKD#%>L*!4_J^&D5ZPD%@NH#
M"1[K!`Z)Z@@)'NL!`=WX,.%/ZK@($>L)`4_J]6D1ZPD!@^H("1[K!`Z)Z@4)
M'NL"#DZ:3^JU!1[K"0Y/ZO%I'NL)#HCJ!0D2&8GJ`0G2&%";3^JQ`1+K"0)/
MZOYI$NL)`H7J`0D;&8GJ#@D3ZP@$W?A(@4_JO@Y/ZO)J%.L)!$OVW$/(]AMS
M%.L*!$'J#@D8ZP,(JD8)Z@()3^JR!1CK"@(!Z@X*W?A0@4GJ"@E.Z@4*$NL)
M`D_J]&D2ZPD""NH$"@[J!0D8ZP,(3^JT!$KJ"0H8ZP$!W?A8D47J!`@:ZP$!
M3^KR:@CJ`@@1ZPH!!>H$"AGK`PE(Z@H(&>L.#D_JL@(8ZPX.W?A@@43J`@I/
MZO%I'NL)#@KJ`0H$Z@()&.L#"$_JL0%*Z@D*&.L%!=WX:)%"Z@$(&NL%!4_J
M_FH(Z@X(%>L*!0+J`0H9ZP,)2.H*"!GK!`1/ZKX.&.L$!-WX<(%!Z@X*3^KU
M:13K"00*Z@4*`>H."1CK`PA/ZK4%2NH)"ACK`@+=^'B13NH%"!KK`@)/ZO1J
M".H$"!+K"@(.Z@4*&>L#"4CJ"@@9ZP$!3^JT!!CK`0'=^("!1>H$"D_J\FD1
MZPD!"NH""@7J!`D8ZP,(3^JR`DKJ"0H8ZPX.W?B(D43J`@@:ZPX.3^KQ:@CJ
M`0@>ZPH.&>L#"03J`@I/ZK$!2.H*"AGK!07=^)"10NH!"!KK!05/ZOYJ%>L*
M!0CJ#@@"Z@$*&>L#"4_JO@Y(Z@H(&>L$"F:<0>H."4_J]6L8ZPH(">H%"1CK
M"P@!Z@X*Y!A/ZK4%2>H*"J08:)I.Z@4)&NL$!$_J^&H4ZPH$#NH%"Q+K`PH)
MZ@@)3^JX`DGJ"PD:ZP$(:IE%Z@(*&>L("4_J]&@*Z@0*&>L("<D8!>H""$_J
MM`1*Z@@($>L.#FR90NH$"ACK#@Y/ZOEH'NL(#@+J!`O)&`KJ"0I/ZKD(31E*
MZ@L);IE$Z@@*&>L%!4_J_FD*Z@X*%>L)!03J"`G)&$_JO@Z)&$KJ"0IPFDCJ
M#@L:ZP$)3^KU:AGK"@D+Z@4!TA@(Z@X+3^JU!4'J"PL2&7*93NH%"D_J^60;
MZP(""NH)"A(9#NH%"\D83^JY!!'K"`A*Z@L)=)E%Z@0*&>L("$_J\FD8ZPD(
M!>H$"Q'K`PD*Z@(*3^JR`4KJ"PH9ZPX.=II$Z@$)&NL.#D_J^&H)Z@@)'NL*
M#@3J`0K2&$_JN`A)Z@H)4AEXG4'J"`H9ZP("3^K^:1+K"0(*Z@X*[1@!Z@@#
M2NH#"BT9>IM/ZKX.&NL%!4SRUA1/ZO)JS/9B)!7K"@6(Z@X)&QF)Z@()61A\
MFT_JL@)/ZO5J$>L)`8[J`@D1ZPH!&QF)Z@4)$^L("'Z;3^JU!1CK"0A/ZO%I
M&.L)"(+J!0D;&8GJ`0D3ZPX.@)L>ZPD)3^JQ`4_J^&Z%Z@$*&>L.#AL9FAB*
MZ@@*@IM/ZK@($NL*"D_J_F(:ZP("@>H("1L9B>H."5T9A)L5ZPD)3^J^#D_J
M\F49ZP4%B.H."1L9B>H""5D8AIL1ZPD)3^JR`D_J]6$9ZP$!CNH""1L9B>H%
M"1/K"`B(FQCK"0E/ZK4%3^KQ:!GK"`B"Z@4)&QF)Z@$)$^L.#HJ;'NL)"4_J
ML0%/ZOAN&>L.#H7J`0D;&8GJ"`F:&(R;$NL)"4_JN`A/ZOYB&>L"`H'J"`D;
M&8GJ#@E=&8Z;%>L)"4_JO@Y/ZO)E&>L%!8CJ#@D;&8GJ`@E9&)";$>L)"4_J
ML@)/ZO5A&>L!`8[J`@D;&8GJ!0D3ZP@(DIL8ZPD)3^JU!4_J\6@9ZP@(@NH%
M"1L9B>H!"1/K#@Z4FQ[K"0E/ZK$!3^KX;AGK#@Z%Z@$)&QF)Z@@)FAB6FQ+K
M"0E/ZK@(3^K^8AGK`@*!Z@@)&QF)Z@X)71F8FQ7K"0E/ZKX.3^KR91GK!06(
MZ@X)&QF)Z@()61B:FQ'K"0E/ZK("3^KU81GK`0&.Z@()&QF)Z@4)$^L(")R;
M&.L)"4_JM05/ZO%H&>L("!L9@NH%"1/K#@Z)Z@$)GIL>ZPD)3^JQ`4_J^&X9
MZPX.&QF%Z@$)FAB)Z@@)H)L2ZPD"3^JX"$_J_FD;&4I$@>H(!(3J#@1;&1L9
M3^KR9"-$3^J^#A/K#`.R&`-@`"2#:1[K!P>"8`)J&.L#`P=AB1B#841@`6(!
MFZ.:Q&`;:$1AFD+$841B`]$-]25]O>CPC_[W+N_T90$`&`$``"WI^$,@2WM$
M`"@XT!]*FUC3^`"0N?$`#S/0`WBS\3T%&+\!)0`K"+\`):VYV?@`0'RQ!T:(
M1DY&*D8Y1B!&__<0Z!"Y8UT]*P_05O@$3P`L\M$@1KWH^(,%1A7X`3\`*QB_
M/2OYT2T:X.<!-:;K"08L1+80R/@`8"!&O>CX@P1&Y^=,1N7G`+]N60$`2`$`
M`/"U@[`53P5&%4ML1G]$_E@S:`&3(48H1O_WJO^PL1%+`)C[6!EH`>N``UIH
M0?@@(``J[]`$,UIH0_@$*P`J^M$A1BA&__>4_P`HZ-$!FC-HFD(!T0.P\+W^
M][3NV%@!`!@!``!(`0``+>GP3PQ&W_A@D86P5TL%1OE$"GA9^`-@/2H(OP$T
M,V@@1@.3_O<4[P*I!T8H1O_W:_^`1@`H5=#^]PKON$)(TDM+`II9^`.03^J"
M""MXL_$]`!B_`2``*PB_`"`XL2A&$/@!/P`K&+\]*_G10!L"-]GX`*`X1/[W
MR.Y*^`@``"AIT-GX`"`H1@*9$/@!.U+X(1`]*QB_`"L+<`G02AP0^`$[$48`
M*QB_/2L"^`$[]M$*1CTC"W`4^`$[`O@!/P`K^=$`(`.:,VB:0DK1!;"]Z/"/
M"/'_,!3X`3L`^`$_`"OYT>[G(DM9^`.0V?@`L-OX`#";LUM&`.!01E/X!"\`
M\0$*`"KXT0,P@``:2GI$$VBSN0$C$V#^]WCN`9#8L4_JB@A91D)&_O?B[0&;
MR?@`,`KQ`0(`(4/X(A#-^`B@A><!1EA&_O<>[D_JB@@#1LGX````*.S13_#_
M,+/GFD8((-/G_O?\[0"_;%@!`!@!``!(`0```%D!`#9+-TI[1"WI\$^?L)U8
M*V@=DQ"Q`W@&1C.Y'9HK:)I"6=$?L+WH\(_^]R;N!T8`*//0W_BP@-_XL)#?
M^+"@^$3Y1/I$.$;^][SN`"@YT`#Q$P1!1B!&_O=P[0`H\M!)1B!&_O=J[0`H
M[-`P1O[W-.Z#1B!&_O<P[EA$`C#^]PCN4T9/\/\R`2$!E`"6@T;^]T+N648"
MJ@,@_O>D[@$P6$8%T`:;`_1P0[/U@$\0T/[WJ.U81O[W9.TX1O[W@NX`*,71
M.$;^]ZSN,$;^]VSMI.?_]Y;_[>?^]X;M`+\`5P$`&`$``,82``#($@``RA(`
M`!1+`48PM7M$$TR=L`5&`R!J1AQ9(V@;D_[WA.YPN02;`_1P0[/U($\8O[/U
M@$\'T!N:(VB:0@O1';`PO0`@]^<H1@(A_O<R[K#Z@/!`">_G_O=0[0Y6`0`8
M`0``+>GP0ZWU@%TI3(.P*4L-]8!6?$0!K8!&)TCG6`0VB49`]O]R*49X1#MH
M,V#^]UKM(DL`*"_=1A[C6*I='&C2N0ZS,D8O(2A&_O?\[=BQ($;^]T;N,T8J
M1D%&_O<2[@WU@%,$,QIH.VB:0A[1#?6`70.PO>CP@P9&+R$R1BA&_O?B[0`H
MX]$@1O[W*NY*1D%&_O<B[>/GXU@<:"!&_O<@[DI&04;^]QCMV>?^]_;L`+^F
M50$`&`$``*(1```@`0``$+4(3`A+?$3C6!AH_O<([@9*!TL'2:)8>T1Y1+WH
M$$#^]WZ]\E0!`"`!```<`0``L!```/X0```-2PY*>T00M8*PG%@@:/[W[.W_
M]]G_(&C^]^;M"$L`(0A*>T3-Z0`Q!TEZ1'E$_O>([0*P$+T`O[Q4`0`@`0``
MJA,``/<,``#0$```($HA2WI$\+6M]0!=U5B'L`WU`%(=3!0R#?6`5BMH?$00
M-A-@_O<$[1E+0?(!`@$A>T3-Z0`$`ZP@1O[W).T@1C%&3_2`4O[WK.P$'KB_
M`"<*VV`<_O?4[`=&*+$Q1B)&_O=2[``C.U4-]0!3.$84,QIH*VB:0@/1#?4`
M70>P\+W^]VCL<%0!`!@!``"V$```F!```/_WM+];2UQ*>T0MZ?!/K?6$79M8
M@[`&1@WUA%(&KU=(!),$,AMH#$9X1#E&$V#_]QW]+R$%1C!&_O?([)BQ4$@Q
M1GA$__>._3!&#?6$4P0S&F@$FQMHFD)`\(F`#?6$70.PO>CPCS!&_O>D[$5)
M>42`1B!&_O<&[8-&`"C?T$)+W_@(H7M$!9.;^``P^D3?^`"1^40`*T30+;%9
M1BA&_O>ZZP`H0]!81O[WA.Q"'@OK`@,;^`(@+RH&T0`A&7`!.!/X`2TO*OG0
M"/$!`QA$L/6`7[3:(:PO2@$A`I9Z1$M&`9(@1D_T@%+-^`"P_O>`[#I&(48#
M(/[WY.PHN3MI`_1P0[/U`$\<T"-)`"!Y1/[WNNR#1KOQ``^1T)OX`#``*[K1
M[;%11BA&_O=TZ^"Y&TD`('E$_O>F[(-&N_$`#^S1?><!(2!&_O>8[``HW-$4
M2"%&>$3_]P;]($;^]ZSK=.?=^!2P`2"OY]-&`2"LY_[WJ.L`O]A3`0`8`0``
M'!````X0``#R#P``7`\``%0/``#2#P``D`\``%0/```N#P``_@X```-X.[%"
M'"\K"+\01A+X`3L`*_C1<$<`OQ"U`"A(T`-X!$8`*T30_O?TZP$X(QB<0@S2
M(EPO*A316AX"X!EX+RD/T:)"$T8"\?\R]]&<0A/1(W@O*S+0'$B]Z!!`>$3^
M]U6[6AX"X!EX+RD%T)1"$T8"\?\R]]/IYP$[`N`1>"\I!-&<0AI&`_'_,_?3
M$AN3'+/U@%^(OP`@"=@,2"%&`3)/](!3>$0$1O[W*NL@1A"]!TB]Z!!`>$3^
M]RB[!4B]Z!!`>$3^]R*[;`X``#Q3`0"&#0``>@T``"WI\$&,L$9,`JU&3WQ$
M1DX,-']$W_@4@0_,^$2_60&N#\4/S-?X`,`/Q21H0$C-^"S`>$0L@/_W(_P^
M2'A$__<?_#U(>$3_]QO\/$AX1/_W%_P[2'A$__<3_#I(>$3_]P_\.4AX1/_W
M"_PX2'A$__<'_$!&__<$_#5(>$3_]P#\-$AX1/_W_/LS2#%&>$3_]Z_[&+$!
M1D!&__<F_"](,49X1/_WI?L@L0%&+4AX1/_W&_PL2#%&>$3_]YK[B+$!1BE(
M>$3_]Q#\*$DI2'E$>$3_]PK\"YH[:)I"'M$,L+WH\($D2#%&>$3_]X+[*+$!
M1B%(>$3_]_C[YN<@20HB#?$9`'E$_O>DZP`HW=$<2`WQ(P%X1/_WZ/O6Y_[W
ME.H`OR@-``!240$`&`$``"H.``#"#0``Q`T``,0-``#(#0``R`T``-`-``!D
M#0``S`T``-8-``!2#0``T`T``-`-``#8#0``V@T```8-``#T#0``3@T``+H-
M``!&#0``L@T``"8-```221-*>4032Q"U>T2,6(*P&&@C:`&30QP%T`&:(VB:
M0A+1`K`0O0Q(:49X1/_W'OLPL0!X,"@8OP`H%+\!(``@!DM[1!A@Z.?^]SKJ
MW$\!`!@!```J40$`B@P``/)0`0`(M?[W\.G^]^+I`+$`:`B](4LB2GM$+>GP
M08:PG%@%1A].!*DC:'Y$,$8%D__W[OHI1A"Q`W@'1E.Y&DAX1/_W8?L%FB-H
MFD(CT0:PO>CP@?[WJND`*/31*$;^]WSJ@$8X1O[W>.I`1`(P_O=0Z@Y+3_#_
M,@*7>T3-Z0!3"TL!(7M$@$;^]X3J048P1O_W.OO7Y_[WYND`OVQ/`0`8`0``
MN@P``*0,``"*"P``A`L``"WI\$^M]0%-W_BL1J>PW_BLE@WUS'M\1-_XI#8B
M'0B0^40$\1`,!\JK\?@'6?@#,*OQX`HH-*OQ[`@.KAU&"I.'Z`<`O.@/`-7X
M`."JZ`\`#?4!0YSH`P"4,\/X`."*Z`,`E.@'`(CH!P`Q1M_X5`9X1/_W<_H@
ML0-X!$8`*T#P>X'_]V7_!48`*`#P48$H1O[W".I```$P_O?@Z2MX"9"#L=_X
M)(8)G/A$`),@1D-&3_#_,@$A`C3^]Q+J%?@!/P`K\M%;^.`,N+&K\=P$`N!4
M^`0+B+$Q1O_W0/H%1@`H]M`#>``K\]#_]^C[`"COT"A&_O=8Z8!&(+L`)%?X
M)%#UL2MXX[$$\0$(*$8'ZX@*1$;_]]/[8+E:^`1;A;$K>'.Q"/$!""A&1$;_
M]\?[`"CRT"A&_O<VZ0`HW]"`1@'@3_``"$!&W_B$1?[WK.D)GWQ$!48X1O[W
MIND%1`7R!$4H1O[W?.G?^&@U3_#_,@$A>T3-Z0$TW_A<-0.7>T3-^`"`@D;^
M]ZSI4$9/].!Q_O>\Z0$P!='^]Y[I`F@1*D#PW(`R1E%&`R#^]QKJ!$;PL=_X
M)"4!(0B;`"=9^`(`W_@<)1MH>D3-^`"@`&C^][KI#?4!0SA&E#,::`J;&VB:
M0D#P4X(-]0%-)["]Z/"/,VD#]'!#L_6`3]K1MVG^]YKHAT+5T3-IP_,(`[/U
MX'_/T2A&_O<DZ3%&!T;?^,0$>$3_]YSY`"@`\+:`")L=:/[WNN@!1BA&__==
M_`5&`"@`\*J`*$;^]R[I`R@&1A#9W_B4%`0X*$1Y1/[W5.A`N00N`/#"@2Y$
M%O@%/"\K`/"\@?_W/OXXN0%&*$;^]^KH"9``*$#PBX#?^&`4W_A@!'E$W_A<
M9'A$W_A<E/_WV_E^1/[W].C?^%`TW_A0%$_P_S)[1`&3W_A(-'E$S?@`H/E$
M`Y%[1`$AW_@\A/A$`I`X1O[W!NDS1E9&FD84X/[W^N@#:!$K%]'^]]+H`33-
M^!"`*D8#E$M&S?@$H`$A`)8"D#A&_O?NZ$_TX'$X1O[W_.A#'`5&XM"R1E!&
M_O<8Z/I(.49X1/_WEODX1O_W&?Y/YP1&".N$!57X!`L@LS%&`33_]PSY`"CV
MT`-X`"OST/[W*N@`*.W0!4:9YM](`2$(FP`G6?@``!MHS>D`HN=*`&AZ1/[W
MZ.@KY__W\OT@1O[W$N@'1B3G#2#A3?[W:.A3(WU$"9"%Y@B;'6A2YZOQ!`-O
M\!$""),")!U&`)1/\/\S_O<\Z"E&!B()F/WWMN\;^`0\&[EK>$,K`/`J@0`D
M`"(`(P"4"9BK\<@&_O<HZ*RAT>D``:RCT^D`([1GQND"`:OQD`$+D:JAT>D`
M`<;I!".IH]/I`"/&Z08!J:'1Z0`!QND((P`B`",,E,;I"B/&Z0PC2^DR`0V7
M3_0`0MWI"!#]]WKO!!YSW=;I"@'G`*!&3^KD>3L8!I,,FS5K=VL'D]WI!B.+
M0@B_@D("T@$U1_$`!T_J6'*P;T+JR0)/ZEES51G=Z0820^L'!S5C=V/&Z0H2
M`"A)T,#Q0`@+FZ!%")D81*B_H$9"1OWW9.^S;T-$LV=`*\#1")LP1J3K"`28
M1/[W#OH_+"C=I/%`"0CQ@`<I\#\#"/%`#A]$KO%`!*OQD`P@:!`T5/@,'&5&
M5/@(+`SQ$`Q4^`0\=$4/Q?'1,$;^]^[Y!/%`#G=%YM%/ZID48QRIZX04".N#
M&$%&2",B1@N8_?=Z[[1GAN?=^""`R><)F*OQD`4-G_[W5.BT:H`@,VO$\\4"
M)+I1')/Z@_@X*:A49MW!\4`":!@`(?WWXN\P1O[WO?DH1C@B`"']]]KOQND<
MA#!&_O>S^:OQ1`*Q:*OQ,`5;^,@\J_%#"PFZ46`Q:1BZW_B,@1L.2_@!#`FZ
ML&GX1)%@+$8Q:@"ZT&`)NA%A`>`;^`$[`),@1D-&3_#_,@$A`C3]]Y3O747R
MT59(3_#_,E5+`2%X1`*5`Y![1,WX`*`X1@&3`".%^"@P4$M[1/WW?N^7Y@B;
M7F@`+C_T/ZXP1OWW5N\#*'_V.:Y)200X,$1Y1/WW?NX`*`B_-48NYF@8P?$X
M`@`A_?=\[Y_G")N;>$$K?_31K@B;VWA#*W_TS*X(FQMY2"M_],>N")M;>44K
M?_3"K@"43_#_,PF<;_`Y`B!&_??J[@B=($8I(C%,*4;]]V#N,$M\1$_P_S)[
M1`&3+DL!(0*5.$;-^`"@>T0#E/WW+.]&YOWWDNX`OXFKS>\`````_MRZF```
M``!V5#(0`````/#ATL,``````2-%9P`````.4`$`L$X!`!@!``#$"@``H`L`
M``P+``#L"0``U`H``"@!``#<"@``U@H``*8*``">"0``$`D``+X(``!N"@``
MK`@``"0+``!:"@``$@L``!((``#T"```L`@``+8&```4"```C@4``"P'````
M!P``<@<``.P$``",!@``F4J:22WI\$]Z1(>PF$L$K@*64%@!:`.0!9'56"AH
M_?=2[P1&*&C]]T[OE/AH,#%&@/AI,(](>$3^]_;^&+$#>#$K`/#G@/_W]_HH
M:/WW.N^)20LC`2)Y1/WW<NX`*&/0ADH!:7I$U?@`H%)HT?@8@`$J6]W?^`BR
M3_2`:8%+`"3`\B`)^T1[1`"3*>`":&8<V_@(`-7X`*"3:%#X)G`)Z@,#L_6`
M;PB_$6D,T%!&`9']]PCO`9D"(P`B"6C]]Q#NU?@`H`%&.$;]]X+M`)M;:``H
M0/"D@`(TG$*`\J*`-$901OWW\.Y!1@`C(D;]]Z[N`48`*,K19$K5^`"@>D12
M:%$>H4(2T0$J$-U@3@$D4$9^1`#@*&C]]];N04;]]X+M<V@!-*-"]=S5^`"@
M4$;]]\KN5TD#(P$B>43]]P+N!$9HL2AH_?>^[B-I4DH9:'I$_?>T[2-I&VB;
M:%L";]0H:/WWL.Y,20,C`2)Y1/WWZ.T$1GBQ24@"F7A$_O=5_@9&*&@`+E#0
M_?>>[B-I,D89:/WWE.TH:/WWENY!3GY$!$8H:/WWD.X_20$B>43]]_+M/4IZ
M1`%&($;]]X#M*&C]]X+N`"("F0-&.$B#^&D@>$3^]RK^!$;P8(BQ3_3@<2!&
M_??X[4,<$2@8OP$K,=@#FP6:&VB:0BK1!["]Z/"/L&C_]V3[!$;P8``HYM$H
M2'A$_??2[4-X`"L_]!>O$^<:1F[G&D8T1FOG_?=,[B%+(FE[1)MH$&@9:/[W
MU/^JYRAH_?=`[B-I&6C]]];MA^?]]Q;M&4D#1AE((D9Y1'A$B6@):/WWJNT`
MOY1'`0`8`0``(`$``!X$``"V!0``R$@!`*A(`0"F2`$`,$@!`!Q(`0#<!```
MR@0``+8$``"4`@``D$<!`'H$``"*!```,@(``#8$``#\1@$`TD8!``P$```X
MM05&__=8^0-X!$8[L4(<+RL(OQ1&$O@!.P`K^-'_]VWZ`"T8OP`H`-$XO2MX
M`"O[T`9)($8$(GE$_??&[0`H\]$H1KWH.$#^]\:^,`(```)+>T0;:/WWM[P`
MO]I%`0`MZ?A#!T8,3HA&#$V11GY$_?<X['U$=ANV$`K0!#T`)`$T5?@$/TI&
M048X1IA'ID+VT;WH^(,`OT)#`0`X0P$`<$<`OPA`+>D(@+WH`0`"`'!E<FQX
M<VDN8P```%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@`````"X`
M```N+@``)7,O)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O
M=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C+R5I
M+R5S`&5X90!005)?5$5-4`````!005)?4%)/1TY!344`````.@```"5S)7,E
M<P``+P```%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/4%0`````4$523$E/
M``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.````4$%2
M7T1%0E5'````4$%27T-!0TA%````4$%27T=,3T)!3%]$14)51P````!005)?
M1TQ/0D%,7U1-4$1)4@```%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!0
M05)?1TQ/0D%,7T-,14%.`````%!!4E]#3$5!3CT``#$```!,1%],24)205)9
M7U!!5$@`4UE35$5-```E,#)X`````"5S)7,E<R5S`````'!A<BT`````)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H
M97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N
M<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I
M;VXI"@``4$%42`````!P87)L`````"YP87(`````)7,E<V-A8VAE+25S)7,`
M`"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S`````$%21U8`````
M&````'!E<FP`````,````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#0W
M````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R
M96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@`````M90``+2T``%5315(`````55-%4DY!344`````
M5$5-4$1)4@!435``+W1M<`````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@
M("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S
M;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]
M*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F
M:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H
M<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*
M<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G
M35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%4
M12`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI
M.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@
M,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?
M=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@
M,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@
M,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE
M("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D
M8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P
M97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%
M1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E
M<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T
M:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E
M>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@
M/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I
M;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E
M=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL
M;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@
M)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@
M)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I
M9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S
M970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS
M965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R
M96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N
M("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD
M:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED
M>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J
M(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`[
M"B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*
M<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C
M:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S
M(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D
M8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F
M.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY
M("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_
M("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@
M;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H
M)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY
M("1F:6QE;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U
M*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N
M86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L
M;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N
M9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?
M=&5M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B
M4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[
M)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U
M;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@
M/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@
M<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R
M96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M
M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E
M7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)
M3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF
M("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I
M*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$[
M"F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E
M96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N
M86UE(#T@7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M(BP@)&9I;&5N
M86UE+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D
M:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*
M<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN
M;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D
M97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*
M<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE
M;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S
M("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2![
M"FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE
M;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@
M/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?
M;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P
M,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A
M<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M
M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2
M155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N
M;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%2
M1U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES
M=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU
M("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(*
M*3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI
M9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*
M?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I
M;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q
M<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@
M0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B
M=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A
M<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE
M;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@
M*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q
M("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E
M;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L
M;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@
M)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD
M,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E
M<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S
M<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*
M97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H
M)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD
M969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X
M*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T
M(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G
M24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*
M?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP
M+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD
M+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ
M72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A
M<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE
M(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H
M)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL
M93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL
M93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I
M.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD
M968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^
M.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_
M.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@
M)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D
M=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF
M("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@
M=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@
M+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N
M("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]
M96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B
M=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I
M.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L
M92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI
M8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D[
M"GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A
M9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?
M97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*
M9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE
M*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*
M96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R
M+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE
M879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E
M9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@
M=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK
M*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB
M7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D
M9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@
M)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M
M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE
M(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT
M96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%2
M7U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N
M="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE
M(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L
M(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P
M.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL
M("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E
M;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54
M;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T
M<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY
M("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^
M;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ
M340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z
M.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N
M,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL
M92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD
M(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M
M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@
M)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M
M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE
M7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F
M:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R
M*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H
M;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D
M("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z
M.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF
M9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ
M3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D
M>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6
M>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I
M;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE
M>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]
M("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@
M/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO
M*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*
M?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I
M;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA
M;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N
M8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R
M7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE
M(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M
M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.
M86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@
M)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E
M.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S
M<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@
M/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D
M;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z
M.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A
M=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E
M<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E
M<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@
M=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U
M=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN
M,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R
M97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER
M92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!0
M97)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I
M<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@
M>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@
M*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)
M4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT
M('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A
M=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`]
M(&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F
M5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G
M:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@
M/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]
M('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O
M7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A
M<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS
M=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O
M9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U
M9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L
M(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*
M96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@
M1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E
M<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*
M:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q
M("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H
M)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD
M<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H
M*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE
M("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@
M,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%
M3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92![
M"FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN
M86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE
M*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F
M:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA
M;64Z("0A(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L
M;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M
M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D
M=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O
M9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%
M3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$[
M"GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I
M;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G
M;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%
M?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@
M>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I
M9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@
M>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R
M96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@
M)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A
M;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I
M9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H
M)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@
M;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]
M"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.
M5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W
M9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D
M*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P
M<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P
M=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.
M251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM0
M05)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@
M0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*
M9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-
M4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!
M4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD
M7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@
M("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.
M5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!
M3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R
M("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@
M)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*
M<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@
M(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I
M;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L
M(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV
M;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V
M96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU
M;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A
M<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP
M="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU
M;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H
M)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I
M9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H
M)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`>)W_
M?P$`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``"M&```;1@```$````!`````0```,L!```!````U@$```$```#@`0```0``
M`"\"```!````B`,```$```"N`P``#````+@2```-````>#H``!D```"$?0$`
M&P````0````:````B'T!`!P````$````]?[_;[0!```%````@`D```8```"@
M`@``"@```!(%```+````$````!4``````````P```+1^`0`"``````(``!0`
M```1````%P```+@0```1````T`\``!(```#H````$P````@````>````"```
M`/O__V\!```(_O__;W`/``#___]O`P```/#__V^2#@``^O__;Q``````````
M````````````````````````````````````````````````C'T!````````
M````Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(``,02
M``#$$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(`
M`,02``#$$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(``,02``#$$@``
MQ!(``,02``#$$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(``,02``#$
M$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(``,02
M``#$$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(``'4Z````````````
M```````````````````````````````````````U.@```````.D5````````
M````````````````!(`!`/_____L/0``M#H```````#4.P``V#L``.`]```<
M.P``Z#T```````#,/0``U#T```````#T/0``1T-#.B`H1&5B:6%N(#@N,BXP
M+3@I(#@N,BXP`$=#0SH@*$1E8FEA;B`W+C,N,"TR.2D@-RXS+C``03(```!A
M96%B:0`!*`````4W+4$`!@H'00@!"0(*!!($$P$4`14!%P,8`1D!&@(<`2(!
M`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U
M:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N
M`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT
M`"YF:6YI`"YR;V1A=&$`+D%232YE>&ED>``N96A?9G)A;64`+FEN:71?87)R
M87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM
M96YT`"Y!4DTN871T<FEB=71E<P``````````````````````````````````
M````````````````````````"P````$````"````5`$``%0!```9````````
M```````!`````````!,````'`````@```'`!``!P`0``(```````````````
M!``````````A````!P````(```"0`0``D`$``"0```````````````0`````
M````-````/;__V\"````M`$``+0!``#L````!0`````````$````!````#X`
M```+`````@```*`"``"@`@``X`8```8````#````!````!````!&`````P``
M``(```"`"0``@`D``!(%``````````````$`````````3@```/___V\"````
MD@X``)(.``#<````!0`````````"`````@```%L```#^__]O`@```'`/``!P
M#P``8`````8````#````!`````````!J````"0````(```#0#P``T`\``.@`
M```%``````````0````(````<P````D```!"````N!```+@0`````@``!0``
M`!4````$````"````'P````!````!@```+@2``"X$@``#```````````````
M!`````````!W`````0````8```#$$@``Q!(``"`#``````````````0````$
M````@@````$````&````Z!4``.@5``"0)``````````````(`````````(@`
M```!````!@```'@Z``!X.@``"```````````````!`````````".`````0``
M``(```"`.@``@#H``*@_``````````````0`````````E@````$``'""````
M*'H``"AZ```(````#0`````````$`````````*$````!`````@```#!Z```P
M>@``!```````````````!`````````"K````#@````,```"$?0$`A'T```0`
M``````````````0````$````MP````\````#````B'T!`(A]```$````````
M```````$````!````,,````&`````P```(Q]`0",?0``*`$```8`````````
M!`````@```#,`````0````,```"T?@$`M'X``$P!``````````````0````$
M````T0````$````#`````(`!``"```!````````````````$`````````-<`
M```(`````P```$"``0!`@```&!``````````````!`````````#<`````0``
M`#``````````0(```#D```````````````$````!````Y0````,``'``````
M`````'F````S```````````````!``````````$````#``````````````"L
7@```]0```````````````0``````````
